@@ -50,7 +50,6 @@
 
 #include <QUrl>
 #include <QString>
-#include <QStringList>
 #include <QWebEnginePage>
 #include <QWebEngineUrlRequestInfo>
 
@@ -60,7 +59,7 @@ static QString toSecondLevelDomain(const QUrl &url)
     const QString urlHost = url.host();
 
     if (topLevelDomain.isEmpty() || urlHost.isEmpty()) {
-        return QString();
+        return {};
     }
 
     QString domain = urlHost.left(urlHost.size() - topLevelDomain.size());
@@ -95,7 +94,7 @@ AdBlockRule::~AdBlockRule()
 
 AdBlockRule* AdBlockRule::copy() const
 {
-    AdBlockRule* rule = new AdBlockRule();
+    auto* rule = new AdBlockRule();
     rule->m_subscription = m_subscription;
     rule->m_type = m_type;
     rule->m_options = m_options;
@@ -418,7 +417,7 @@ void AdBlockRule::parseFilter()
     // Parse all options following $ char
     int optionsIndex = parsedLine.indexOf(QL1C('$'));
     if (optionsIndex >= 0) {
-        const QStringList options = parsedLine.mid(optionsIndex + 1).split(QL1C(','), QString::SkipEmptyParts);
+        const QStringList options = parsedLine.mid(optionsIndex + 1).split(QL1C(','), Qt::SkipEmptyParts);
 
         int handledOptions = 0;
         for (const QString &option : options) {
@@ -606,9 +605,9 @@ void AdBlockRule::parseFilter()
 
 void AdBlockRule::parseDomains(const QString &domains, const QChar &separator)
 {
-    const QStringList domainsList = domains.split(separator, QString::SkipEmptyParts);
+    const QStringList domainsList = domains.split(separator, Qt::SkipEmptyParts);
 
-    for (const QString domain : domainsList) {
+    for (const QString &domain : domainsList) {
         if (domain.isEmpty()) {
             continue;
         }
