@@ -19,6 +19,7 @@
 #define QZTOOLS_H
 
 #include <QFileDialog>
+#include <QStylePainter>
 
 #include "qzcommon.h"
 
@@ -51,7 +52,7 @@ public:
     static QString fromPunycode(const QString &str);
     static QString escapeSqlGlobString(QString urlString);
 
-    static QString ensureUniqueFilename(const QString &name, const QString &appendFormat = QString("(%1)"));
+    static QString ensureUniqueFilename(const QString &name, const QString &appendFormat = QSL("(%1)"));
     static QString getFileNameFromUrl(const QUrl &url);
     static QString filterCharsFromFilename(const QString &name);
 
@@ -76,13 +77,13 @@ public:
     static bool containsSpace(const QString &str);
 
     // QFileDialog static functions that remembers last used directory
-    static QString getExistingDirectory(const QString &name, QWidget* parent = 0, const QString &caption = QString(), const QString &dir = QString(), QFileDialog::Options options = QFileDialog::ShowDirsOnly);
-    static QString getOpenFileName(const QString &name, QWidget* parent = 0, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = 0, QFileDialog::Options options = 0);
-    static QStringList getOpenFileNames(const QString &name, QWidget* parent = 0, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = 0, QFileDialog::Options options = 0);
-    static QString getSaveFileName(const QString &name, QWidget* parent = 0, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = 0, QFileDialog::Options options = 0);
+    static QString getExistingDirectory(const QString &name, QWidget* parent = nullptr, const QString &caption = QString(), const QString &dir = QString(), QFileDialog::Options options = QFileDialog::ShowDirsOnly);
+    static QString getOpenFileName(const QString &name, QWidget* parent = nullptr, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = nullptr, QFileDialog::Options options = {});
+    static QStringList getOpenFileNames(const QString &name, QWidget* parent = nullptr, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = nullptr, QFileDialog::Options options = {});
+    static QString getSaveFileName(const QString &name, QWidget* parent = nullptr, const QString &caption = QString(), const QString &dir = QString(), const QString &filter = QString(), QString* selectedFilter = nullptr, QFileDialog::Options options = {});
 
     static bool matchDomain(const QString &pattern, const QString &domain);
-    static QKeySequence actionShortcut(QKeySequence shortcut, QKeySequence fallBack, QKeySequence shortcutRtl = QKeySequence(), QKeySequence fallbackRtl = QKeySequence());
+    static QKeySequence actionShortcut(const QKeySequence &shortcut, const QKeySequence &fallBack, const QKeySequence &shortcutRtl = QKeySequence(), const QKeySequence &fallbackRtl = QKeySequence());
 
     static QString operatingSystem();
     static QString cpuArchitecture();
@@ -95,6 +96,8 @@ public:
     {
         return (index >= 0 && container.count() > index);
     }
+
+    static void paintDropIndicator(QWidget *widget, const QRect &r);
 };
 
 #endif // QZTOOLS_H
